;; LPGAV1

;;;;;;;;;;;;;;;;;;;;;;;;
;; Declarations       ;;
;;;;;;;;;;;;;;;;;;;;;;;;

globals
[
  pros      ;; the professional golf turtles
  crowd     ;; the audience
  shooters  ;; the villian
  law       ;; the pursuer of the villian
  clubhse   ;; clubhse location (list), start for pros and law
  tee?      ;; logic, if = 1 headed towards a tee, if = 0 headed towards a green
  hole-no   ;; defines the hole number that pro is headed towards
  emergency ;; boolean that defines whether or not the stalker is active.
  
  ;; patch agent sets
  fairway  ;; golf fairway, off limits to crowds
  t_holes  ;; teeing ground for holes, off limits to crowds
  greens   ;;location of golf holes, off limits to crowds
  trees    ;; trees and bushes, off limits to crowds
  tees     ;; the physical location of the tee spot for each hole
  holes    ;; the physical location of the cup for each hole
  rough
  water
  course   ;; everything else, pcolor = black
  numHoles ;; the number of holes/tees in the course. this * 2 will be the length of the tees and holes array
  
  ;;patchsets that indicate where one can walk
  okay ;;you can walk here. Grass, roads and such
  emergencyOnly ;;usually no, but can when there's danger. Sand
  no ;;unwalkable. buildings, water
  
  
  
  
]

;;variables defined for the turtles and patches themselves. These are not global
  patches-own[setNum] ;;0 - okay, 1 - emergencyOnly, 2-no
  
  turtles-own[
    flockmates ;; turtles that are close are considered to be part of their flock
    nearest-flockmate ;; the nearest turtle in our flock
  ]

;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Setup Procedures       ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to setup
  ca
  ; setup-globals
  
;;import-pcolors "LocustHill_V0.bmp"
import-pcolors "LocustHillGIS.jpg"

set emergency false;

;; set up clubhouse
ask patches [
if (pxcor > -170) and (pxcor < -150) and
  (pycor > 65) and (pycor < 75) [set pcolor cyan] ]

;;set up the colors for the imported images such that there will be four distinct areas
ask patches [
  if(shade-of? green pcolor) [ set pcolor green] ];green for the fairway, green, and grass
ask patches [;;try using the ones and decimal place (mod 10?). If its between 9 and 9.9, use it
  ;if(shade-of? yellow pcolor or shade-of? orange pcolor) [ set pcolor 44] ];yellow for the sand traps
  if( (pcolor mod 10 > 8.5) ) [ set pcolor 44 ] ]
ask patches [
  ;if(shade-of? blue pcolor) [set pcolor blue] ];blue for the water
  if( (pcolor >= 70) and (pcolor < 120) and (pcolor mod 10 >= 0) and (pcolor mod 10 <= 2))[set pcolor blue] ]
ask patches [
  if((pcolor != green) and (pcolor != blue) and (pcolor != 44) and (pcolor != orange)) [ set pcolor black] ];the rest will be black


;;setting the course will be done by clicking. check on this later
set course patches with [pcolor = white]


;;clean up the green areas, then the blue and then the yellow. Do this so that the water extrudes into the land and not visa versa
;;make sure to check that the interum colors don't eat up what already exists
;ask patches [
  ;if(pcolor = green) [ ask neighbors [ if( (pcolor != green) and (pcolor != blue) and (pcolor != 44)) [ set pcolor green ] ] ] ]
;repeat 1[ ask patches [
  ;if(pcolor = blue) [ ask neighbors [  if( (pcolor != green) and (pcolor != blue) and (pcolor != 44)) [ set pcolor blue ] ] ] ] ]
;repeat 1[ask patches [
  ;if(pcolor = 44) [ ask neighbors [  if( (pcolor != green) and (pcolor != blue) and (pcolor != 44)) [ set pcolor 44 ] ] ] ] ]


;there will be no trees ONLY GRASS THERE CAN ONLY BE ONE
;set trees patches with [(pcolor > 56.0) and (pcolor < 65)]
;ask trees 
  ;[if any? trees in-radius 1 with [pcolor < 55] 
    ;[ask neighbors [set pcolor 65] ] ]
;    [if ([pcolor] of any? (patches in-radius 1) < 55)
;    [ask neighbors [set pcolor 65] ] ]

;using the interum colors as an indicator, flip them to what they should be
;ask patches [
 ; if(shade-of? cyan pcolor) [ set pcolor green] ];green for the fairway, green, and grass
;ask patches [
 ; if(shade-of? pink pcolor) [ set pcolor 44] ];yellow for the sand traps
;ask patches [
 ; if(shade-of? violet pcolor) [set pcolor blue] ];blue for the water


;;set the patch sets once the colors have been fully determined
setupPatchSets

;; setup tees and holes as lists
set clubhse [-160 70]
;set tees [-176 -24 111 11]
;set holes [105 -37 -154 32]
set tees  [-177 4 -27 23]
set holes [14 64 -186 -64]
set hole-no 0 ; start at "hole zero"
set tee? 1    ;; start by heading towards a tee, the first one
set numHoles 2 ;;there are only 2 holes




setup-pros
setup-shooter
setup-crowds

repeat 0 [
  expand emergencyOnly
  expand no
  reassignPatchesToSets
]

ask patches[
  
  if([setNum] of self = 0)
  [set pcolor black]
  
  if([setNum] of self = 1)
  [set pcolor 44]
  
  if([setNum] of self = 2)
  [set pcolor blue]
]
  
ask patches [ set pcolor black ]
;;reimport the image 
import-pcolors "LocustHillGIS.jpg"

ask patches[
  
  ;if([setNum] of self = 0)
  ;[set pcolor black]
  
  if([setNum] of self = 1)
  [set pcolor 44]
  
  if([setNum] of self = 2)
  [set pcolor blue]
]
end

to setup-shooter
  crt 1
   [
     set shape "target"
     set color yellow
     set size 1
   ]
  set shooters turtles with
   [ color = yellow ]
  ask shooters [ put-on-course ]
end
  
to setup-pros
  let x item 0 clubhse
  let y item 1 clubhse
  crt 1
    [
    setxy x y
    set shape "star"
    set color magenta
    set size 5
    ]
set pros turtles with 
  [color = magenta]
end

to setup-crowds
  crt crowd-size
  [
  ;put-on-course
  set shape "circle"
  set color yellow
  set size 1
  ]
set crowd turtles with
  [color = yellow]
ask crowd [ put-on-course ]
end

to put-on-course
  move-to one-of okay with
    [(not any? turtles-on self) and
    (distancexy (item 0 clubhse) (item 1 clubhse)  > 25 and 
      distancexy (item 0 clubhse) (item 1 clubhse)  < 100)
    ]
end

to setupPatchSets
  set emergencyOnly patches with [ (pcolor = 44) ]
  ask emergencyOnly[set setNum 1 ]
  set no patches with [ 
                        (pcolor = blue) or
                        (pycor < min-pycor + buffer-zone) or 
                        (pycor > max-pycor - buffer-zone) or 
                        (pxcor < min-pxcor + buffer-zone) or
                        (pxcor > max-pxcor - buffer-zone)
                       ]
  ask no [ set setNum 2]
  set okay patches with [ 
                        ((pcolor = green) or (pcolor = black)) and 
                        (not 
                          (setNum = 2) 
                          ;(pycor < min-pycor + buffer-zone) or 
                          ;(pycor > max-pycor - buffer-zone) or 
                          ;(pxcor < min-pxcor + buffer-zone) or
                          ;(pxcor > max-pxcor - buffer-zone)
                          )
                        ]
  ask okay [ set setNum 0 ]
end
  
to reassignPatchesToSets
  set no patches with [ setNum = 2 ]
  set emergencyOnly patches with [ setNum = 1]
  set okay patches with [ setNum = 0 ]
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Runtime Procedures       ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to go
  play
  crowd-moves
  ;crowdMovement
  stalkerCheck
  tick
end

to expand [patchSet]
  let thisSetNum -1
  ask patchSet [
    set thisSetNum ([setNum] of self)
    ;show thisSetNum
    ask neighbors [
      if([setNum] of self != thisSetNum)
      [set setNum 777]
    ]
  ]
  ask patches[
    if([setnum] of self = 777)
    [set setNum thisSetNum]
  ]
end

to stalkerCheck
  if(ticks > 10000)
  [set emergency true]
end        

to play
  ifelse tee? = 1
    [ask pros
      ; pro-search randomizes the progress of the pro 
      [facexy ((item hole-no tees) + random-normal 0 pro-search) 
        ((item (hole-no + 1) tees) + random-normal 0 pro-search)]
        every pro-delay [pro-moves];;[ask pros
        ;;[fd pro-speed] ] 
      ask pros 
      [if patch-here = patch (item hole-no tees) (item (hole-no + 1) tees)
        [set tee? 0
        repeat 100 [crowd-moves] ] ]
      ] 
      [ask pros
        [facexy ((item hole-no holes) + random-normal 0 pro-search) 
          ((item (hole-no + 1) holes) + random-normal 0 pro-search)]
      every pro-delay [pro-moves];;[ask pros
        ;;[fd pro-speed] ]
      ask pros 
      [if patch-here = patch (item hole-no holes) (item (hole-no + 1) holes)
        [set hole-no (setHoleNo) 
        set tee? 1] ]
      ]
end

to crowd-moves
  let R 90 * (2 * (random 2) - 1)
  ask crowd
    [ face turtle 0]
  ask crowd
    [ ifelse (canMove)
      [ fd crowd-speed]
      [ rt R
        ifelse (canMove)
          [ fd crowd-speed]
          [ set R (- R)
            rt R
            if (canMove)
              [fd crowd-speed]
          ]
      ]
    ]
end

to pro-moves
  let R 90 * (2 * (random 2) - 1)
  ;;pro is already set to face in the correct direction
  ask pros
    [ ifelse (canProMove)
      [fd pro-speed]
      [rt R
        ifelse (canProMove)
          [ fd pro-speed]
          [ set R (- R)
            rt R
            if (canProMove)  
              [fd pro-speed] 
          ]
      ]
    ]
end

to-report setHoleNo
  let newHoleNo (hole-no + 2)
  if(newHoleNo > 3) [ set newHoleNo (newHoleNo - ( 2 * numHoles )) ]
  report newHoleNo
end




to crowdMovement
  flock
  advance
end



to crowdMovementEmergency
end







to proMovement
end


to proMovementEmergency
end


to advance
  ask crowd[
    fd crowd-speed
  ]
end


to flock
  let seekTarget item 0 pros;
  ask crowd[
    construct-flockmates
    if any? flockmates
    [
      find-nearest-flockmate
      ifelse distance nearest-flockmate < 0; minimum-separation
      [separate]
      [align
      cohere
      seek seekTarget
      ]
    ]
  ]
end

to construct-flockmates
  set flockmates other turtles in-radius sight
end

to find-nearest-flockmate
  set nearest-flockmate min-one-of flockmates [distance myself]
end


;SEPARATE FUNCTIONS
to separate
  turn-away ([heading] of nearest-flockmate) max-separate-turn
end

;ALIGN FUNCTIONS
to align
  turn-towards average-flockmate-heading max-align-turn
end

to-report average-flockmate-heading
  ;; We can't just average the heading variables here.
  ;; For example, the average of 1 and 359 should be 0,
  ;; not 180.  So we have to use trigonometry.
  ;the 'towards me' is in the opposite direction, so 180 is added to flip it
  let x-component mean [sin heading] of flockmates
  let y-component mean [cos heading] of flockmates
  ifelse x-component = 0 and y-component = 0
     [ report heading ]
     [ report atan x-component y-component ]
end


;COHERE FUNCTIONS
to cohere
  turn-towards average-heading-towards-flockmates max-cohere-turn
end

to-report average-heading-towards-flockmates
  ;the 'towards me' is in the opposite direction, so 180 is added to flip it
  let x-component mean [sin (towards myself + 180)] of flockmates
  let y-component mean [cos (towards myself + 180)] of flockmates
  ifelse x-component = 0 and y-component = 0
     [ report heading ]
     [ report atan x-component y-component ]
end

;SEEK FUNCTIONS
to seek [ target ]
  let targetLookAtMe towards target;
  let meLookAtTarget targetLookAtMe + 180;
  turn-towards meLookAtTarget max-cohere-turn;
end
  

;TURNING FUNCTIONS
to turn-towards [new-heading max-turn]
  turn-at-most (subtract-headings new-heading heading) max-turn
end

to turn-away [new-heading max-turn]
  turn-at-most (subtract-headings heading new-heading) max-turn
end

to turn-at-most [turn max-turn]
    ifelse abs turn > max-turn
    [ ifelse turn > 0
      [ rt max-turn]
      [ lt max-turn]
    ]
    [rt turn]
end




to-report canMove
  let movingOkay (false)
  if
    (not any? turtles-on patch-ahead 1) and
    ([setNum] of patch-ahead 1 != 1) and
    ([setNum] of patch-ahead 1 != 2) and
    (not any? pros in-radius pro-radius)
    [set movingOkay true]
  report movingOkay
end

to-report canMoveEmergency
  let movingOkay (false)
  if
    (not any? turtles-on patch-ahead 1) and
    ([setNum] of patch-ahead 1 != 2) and
    (not any? pros in-radius pro-radius)
    [set movingOkay true]
  report movingOkay
end
  

to-report canProMove
  let movingOkay (false)
  if
    ;([setNum] of patch-ahead 1 != 1) and
    ([setNum] of patch-ahead 1 != 2)
    [set movingOkay true]
    ;show movingOkay
  report movingOkay
end
@#$#@#$#@
GRAPHICS-WINDOW
210
10
1022
683
200
160
2.0
1
10
1
1
1
0
0
0
1
-200
200
-160
160
0
0
1
ticks

BUTTON
28
24
94
57
setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

SLIDER
8
220
180
253
crowd-size
crowd-size
25
1000
25
25
1
NIL
HORIZONTAL

SLIDER
5
287
177
320
law_size
law_size
1
10
4
1
1
NIL
HORIZONTAL

SLIDER
7
322
179
355
no_pros
no_pros
1
10
1
1
1
NIL
HORIZONTAL

BUTTON
110
25
173
58
Go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL

SLIDER
8
119
180
152
pro-speed
pro-speed
0.1
1
1
.05
1
NIL
HORIZONTAL

SLIDER
7
253
179
286
crowd-speed
crowd-speed
0.5
1
0.5
.05
1
NIL
HORIZONTAL

SLIDER
7
153
179
186
pro-search
pro-search
0
30
20
1
1
NIL
HORIZONTAL

SLIDER
7
187
179
220
pro-radius
pro-radius
1
20
13
1
1
NIL
HORIZONTAL

SLIDER
7
84
179
117
pro-delay
pro-delay
0
1
0.05
.01
1
NIL
HORIZONTAL

SLIDER
11
370
183
403
buffer-zone
buffer-zone
0
100
1
1
1
NIL
HORIZONTAL

BUTTON
16
608
152
641
Show only the map
ask patches [ set pcolor black ]\n;;reimport the image \nimport-pcolors \"LocustHillGIS.jpg\"
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
20
673
170
706
Show map with zones
ask patches [ set pcolor black ]\n;;reimport the image \nimport-pcolors \"LocustHillGIS.jpg\"\n\nask patches[\n  \n  ;if([setNum] of self = 0)\n  ;[set pcolor black]\n  \n  if([setNum] of self = 1)\n  [set pcolor 44]\n  \n  if([setNum] of self = 2)\n  [set pcolor blue]\n]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
23
727
147
760
Show only zones
ask patches [ set pcolor black ]\nask patches[\n  \n  if([setNum] of self = 1)\n  [set pcolor 44]\n  \n  if([setNum] of self = 2)\n  [set pcolor blue]\n]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

SLIDER
18
421
197
454
max-align-turn
max-align-turn
0
100
50
.25
1
degrees
HORIZONTAL

SLIDER
3
466
206
499
max-separate-turn
max-separate-turn
0
100
50.25
.25
1
degrees
HORIZONTAL

SLIDER
18
563
190
596
sight
sight
0
100
50
.25
1
patches
HORIZONTAL

SLIDER
17
517
209
550
max-cohere-turn
max-cohere-turn
0
100
50
.25
1
degrees
HORIZONTAL

@#$#@#$#@
WHAT IS IT?
-----------
This section could give a general understanding of what the model is trying to show or explain.


HOW IT WORKS
------------
This section could explain what rules the agents use to create the overall behavior of the model.


HOW TO USE IT
-------------
This section could explain how to use the model, including a description of each of the items in the interface tab.


THINGS TO NOTICE
----------------
This section could give some ideas of things for the user to notice while running the model.


THINGS TO TRY
-------------
This section could give some ideas of things for the user to try to do (move sliders, switches, etc.) with the model.


EXTENDING THE MODEL
-------------------
This section could give some ideas of things to add or change in the procedures tab to make the model more complicated, detailed, accurate, etc.


NETLOGO FEATURES
----------------
This section could point out any especially interesting or unusual features of NetLogo that the model makes use of, particularly in the Procedures tab.  It might also point out places where workarounds were needed because of missing features.


RELATED MODELS
--------------
This section could give the names of models in the NetLogo Models Library or elsewhere which are of related interest.


CREDITS AND REFERENCES
----------------------
This section could contain a reference to the model's URL on the web if it has one, as well as any other necessary credits or references.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 4.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
